%CT 1/2012
%this script is responsible for loading images from the Extended YaleB
%database
%e.g. traininds = 11:38,
% testinds = 1:10

function [ YaleData YaleTest] = load_ExtendedYaleB(train_inds, test_inds, IMSIZE)

if nargin < 3    
    IMSIZE = 48;
end

assert( max(train_inds) <= 38 && max(test_inds) <= 38);
assert( min(train_inds) >= 1 && min(test_inds) >= 1);
assert(length(train_inds)+length(test_inds) == 38);

YALEPATH = './YaleBCropped/';

%subset 1
sub1 = {'A+000E+00'; 'A-010E+00'; 'A+010E+00'; 'A-005E+10';
        'A+005E+10'; 'A-005E-10'; 'A+005E-10'};
 
%Subset 2 --  20<angle<25 degrees from optical axis

sub2 = {'A+000E-20'; 'A-010E-20'; 'A+020E-10'; 'A-025E+00';
         'A-015E+20'; 'A-020E-10'; 'A+000E+20'; 'A+010E-20';
         'A+020E+10'; 'A+025E+00'; 'A+015E+20'; 'A-020E+10'};
 
%Subset 3 --  35<angle<50 degrees from optical axis
sub3 = {'A+000E-35'; 'A-035E+15'; 'A-035E-20'; 'A-020E-40';
         'A-035E+40'; 'A-050E+00'; 'A+000E+45'; 'A+035E+15';
         'A+035E-20'; 'A+020E-40'; 'A+035E+40'; 'A+050E+00'};
     
%Subset 4 --  60<angle<77 degrees from optical axis
sub4 = {'A-050E-40'; 'A+060E-20'; 'A-060E-20'; 'A-035E+65';
         'A-070E+00'; 'A-070E-35'; 'A-070E+45'; 'A+050E-40';
         'A+060E+20'; 'A-060E+20'; 'A+035E+65'; 'A+070E+00';
         'A+070E-35'; 'A+070E+45'};

inds1 = randperm(length(sub1));
inds2 = randperm(length(sub2));
inds3 = randperm(length(sub3));
inds4 = randperm(length(sub4));

%test_names = [sub1(inds1(1:3)); sub2(inds2(1:3)); sub3(inds3(1:3)); sub4(inds4(1:3))];
%train_names = [sub1(inds1(4:end)); sub2(inds2(4:end)); sub3(inds3(4:end)); sub4(inds4(4:end))];

train_names = [sub1; sub2; sub3; sub4]; %use all images, but leave some subjects out
subset_ids = [  1*ones(size(sub1)); 
                2*ones(size(sub2));
                3*ones(size(sub3));
                4*ones(size(sub4));]; %use all images, but leave some subjects out
     
sDir = dir(YALEPATH);
assert(length(sDir) == 40);

YaleData=[];
YaleTest=[];

clear YaleData;
clear YaleTest;

for bb = train_inds+2
    FOLDERPATH = [YALEPATH sDir(bb).name ];    
    ind = 1;
    for kkk = 1:length(train_names)        
        filename = [FOLDERPATH '/' sDir(bb).name '_P00' train_names{kkk} '.pgm'];
        if isempty(dir(filename))            
            continue;
        end
        
        im = imread( filename);
        if size(im,3) > 1
            im = rgb2gray(im);
        end
        im = single(im)./255;
        im = min(max(imresize(im, IMSIZE*[1 1]),0), 1);
        YaleData{bb-2}.image( ind, :) = sc(im');
        YaleData{bb-2}.y(ind,:) = bb-2;
        YaleData{bb-2}.subset(ind,1) = subset_ids(kkk);
        YaleData{bb-2}.lighting(ind,1) = kkk;
        ind = ind + 1;
    end
    bb
end %bb

for bb = test_inds+2,
    FOLDERPATH = [YALEPATH sDir(bb).name ];   
    ind = 1;
	for kkk = 1:length(train_names)
        
        filename = [FOLDERPATH '/' sDir(bb).name '_P00' train_names{kkk} '.pgm'];
        if isempty(dir(filename))            
            continue;
        end
        
        im = imread( filename );
        if size(im,3) > 1
            im = rgb2gray(im);
        end
        im = single(im)./255;
        im = min(max(imresize(im, IMSIZE*[1 1]),0), 1);
        YaleTest{bb-2}.image( ind, :) = sc(im');
        YaleTest{bb-2}.y(ind,:) = bb-2;
        YaleTest{bb-2}.subset(ind,1) = subset_ids(kkk);
        YaleTest{bb-2}.lighting(ind,1) = kkk;
        ind = ind + 1;
    end 
    bb
end %bb

